summaryrefslogtreecommitdiffstats
path: root/src/toplevel.h
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
commit6392f5a9dfce2bf83617d49bb7f332181ec6004e (patch)
treeab69e390f7962b7e7dda1a3a64f035c61c751cf4 /src/toplevel.h
parentaba2788b428dc53243407902e9ccbb20b97a69fd (diff)
downloadtdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.tar.gz
tdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.zip
Revert "Finish renaming tdevelop components"
This reverts commit 722ce1efbac31c61b1d4b13f7e075c9f311e3e73.
Diffstat (limited to 'src/toplevel.h')
-rw-r--r--src/toplevel.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/toplevel.h b/src/toplevel.h
index 081ddcae..8eb0243a 100644
--- a/src/toplevel.h
+++ b/src/toplevel.h
@@ -2,10 +2,10 @@
#define __TOPLEVEL_H__
#include "tdevmainwindow.h"
/**\brief This class handles the single object of type TDevMainWindow.
It is completely static (all methods and attributes).
*/
@@ -14,13 +14,13 @@ class TopLevel
{
public:
- static TDevMainWindow *getInstance(); //!< Get a pointer to the single KDevTopLevel object
+ static KDevMainWindow *getInstance(); //!< Get a pointer to the single KDevTopLevel object
static bool mainWindowValid();
- static void invalidateInstance(TDevMainWindow *instance); //!< Signal that the object has been (or is about to be) destroyed
+ static void invalidateInstance(KDevMainWindow *instance); //!< Signal that the object has been (or is about to be) destroyed
private:
- static TDevMainWindow *s_instance; //!< Pointer to the single KDevTopLevel object or 0L
+ static KDevMainWindow *s_instance; //!< Pointer to the single KDevTopLevel object or 0L
};
@@ -2,10 +2,10 @@
#define __TOPLEVEL_H__
-#include "tdevmainwindow.h"
+#include "kdevmainwindow.h"
-/**\brief This class handles the single object of type TDevMainWindow.
+/**\brief This class handles the single object of type KDevMainWindow.
It is completely static (all methods and attributes).
*/